@@ -59,20 +59,6 @@ MappingProtocolChannel *daemon_ioc = NULL;
 
 #undef DEBUG_ENABLE
 
-#ifdef DEBUG_ENABLE
-#ifdef G_HAVE_ISO_VARARGS
-#  define DEBUG_PRINT(...) debug_print (__VA_ARGS__);
-#elif defined(G_HAVE_GNUC_VARARGS)
-#  define DEBUG_PRINT(args...) debug_print (args);
-#endif
-#else
-#ifdef G_HAVE_ISO_VARARGS
-#  define DEBUG_PRINT(...)
-#elif defined(G_HAVE_GNUC_VARARGS)
-#  define DEBUG_PRINT(args...)
-#endif
-#endif
-
 typedef struct {
 	char                   *root;
 	int                     pos;
@@ -92,36 +78,50 @@ typedef struct {
 	gboolean     cancelled;
 } VirtualFileMonitorHandle;
 
+
 #ifdef DEBUG_ENABLE
-static FILE *debug_out = NULL;
+#ifdef G_HAVE_ISO_VARARGS
+#  define DEBUG_PRINT(...) profile_log (G_STRFUNC, NULL, __VA_ARGS__);
+#elif defined(G_HAVE_GNUC_VARARGS)
+#  define DEBUG_PRINT(args...) profile_log (G_STRFUNC, NULL, args);
+#endif
+#else
+#ifdef G_HAVE_ISO_VARARGS
+#  define DEBUG_PRINT(...)
+#elif defined(G_HAVE_GNUC_VARARGS)
+#  define DEBUG_PRINT(args...)
+#endif
+#endif
 
+#ifdef DEBUG_ENABLE
 static void
-debug_init (void)
+profile_log (const char *func,
+	     const char *note,
+	     const char *format,
+	     ...)
 {
-	const char path [50] = "mapping_method_debug_XXXXXX";
-	int  fd = g_file_open_tmp (path, NULL, NULL);
-	if (fd >= 0) {
-		debug_out = fdopen (fd, "a");
-	}
-}
+        va_list args;
+        char   *str;
+        char   *formatted;
 
-static void
-debug_print (const char *format, ...)
-{
-	va_list args;
-	char    buffer [1025];
+        if (format == NULL) {
+                formatted = g_strdup ("");
+        } else {
+        	va_start (args, format);
+        	formatted = g_strdup_vprintf (format, args);
+        	va_end (args);
+        }
 
-	va_start (args, format);
-	g_vsnprintf (buffer, 1024, format, args);
-	va_end (args);
+        if (func != NULL) {
+                str = g_strdup_printf ("MARK: %s %s: %s %s", g_get_prgname(), func, note ? note : "", formatted);
+        } else {
+                str = g_strdup_printf ("MARK: %s: %s %s", g_get_prgname(), note ? note : "", formatted);
+        }
 
-	fprintf ((debug_out ? debug_out : stderr),
-		 "[%p] %s",
-		 g_thread_self (), buffer);
+        g_free (formatted);
 
-	if (debug_out) {
-		fflush (debug_out);
-	}
+        g_access (str, F_OK);
+        g_free (str);
 }
 #endif
 
@@ -171,7 +171,7 @@ process_event (MappingProtocolMonitorEvent *event)
 	GnomeVFSMonitorEventType  event_type;
 
 	if (!event->userdata) {
-		DEBUG_PRINT ("Received event with no userdata, skipping\n");
+		DEBUG_PRINT ("Received event with no userdata, skipping");
 		return;
 	}
 
@@ -201,7 +201,7 @@ process_event (MappingProtocolMonitorEvent *event)
 			info_uri = gnome_vfs_uri_append_file_name (handle->uri, event->path);
 		}
 
-		DEBUG_PRINT ("Returning event %d path %s handle %p\n",
+		DEBUG_PRINT ("Returning event %d path %s handle %p",
 			     event_type,
 			     event->path,
 			     handle);
@@ -212,7 +212,7 @@ process_event (MappingProtocolMonitorEvent *event)
 					    event_type);
 		gnome_vfs_uri_unref (info_uri);
 	} else {
-		DEBUG_PRINT ("Cancelled event %d path %s handle %p\n",
+		DEBUG_PRINT ("Cancelled event %d path %s handle %p",
 			     event_type,
 			     event->path,
 			     handle);
@@ -232,7 +232,7 @@ request_op (gint32                   operation,
 	MappingProtocolMessage *message;
 	MappingProtocolRequest *request;
 
-	DEBUG_PRINT ("request_op: %d\n", operation);
+	DEBUG_PRINT ("request_op: %d", operation);
 
 	message = mapping_protocol_message_new_request ();
 	request = MAPPING_PROTOCOL_REQUEST (message);
@@ -247,9 +247,9 @@ request_op (gint32                   operation,
 	res = mapping_protocol_channel_send_with_reply (daemon_ioc, message, reply);
 
 	if (! res) {
-		DEBUG_PRINT ("request_op: send ERROR\n");
+		DEBUG_PRINT ("request_op: send ERROR");
 	} else {
-		DEBUG_PRINT ("request_op: send OK\n");
+		DEBUG_PRINT ("request_op: send OK");
 	}
 
 	return res;
@@ -293,7 +293,7 @@ do_open (GnomeVFSMethod        *method,
 	char                   *path;
 	MappingProtocolMessage *reply;
 
-	DEBUG_PRINT ("do_open: %s\n", uri->text);
+	DEBUG_PRINT ("do_open: %s", uri->text);
 
 	*method_handle = NULL;
 	path = get_path_from_uri (uri);
@@ -357,7 +357,7 @@ do_create (GnomeVFSMethod        *method,
 	GnomeVFSHandle         *file_handle;
 	VirtualFileHandle      *handle;
 
-	DEBUG_PRINT ("do_create: %s\n", uri->text);
+	DEBUG_PRINT ("do_create: %s", uri->text);
 
 	*method_handle = NULL;
 	path = get_path_from_uri (uri);
@@ -416,7 +416,7 @@ do_close (GnomeVFSMethod       *method,
 	VirtualFileHandle *vfh;
 	GnomeVFSHandle    *handle;
 
-	DEBUG_PRINT ("do_close: %p\n", method_handle);
+	DEBUG_PRINT ("do_close: %p", method_handle);
 
 	vfh    = (VirtualFileHandle *)method_handle;
 	handle = vfh->handle;
@@ -435,7 +435,7 @@ do_read (GnomeVFSMethod       *method,
 	 GnomeVFSFileSize    *bytes_read,
 	 GnomeVFSContext     *context)
 {
-	DEBUG_PRINT ("do_read: %p\n", method_handle);
+	DEBUG_PRINT ("do_read: %p", method_handle);
 	return gnome_vfs_read_cancellable (((VirtualFileHandle *)method_handle)->handle,
 					   buffer,
 					   num_bytes,
@@ -451,7 +451,7 @@ do_write (GnomeVFSMethod       *method,
 	  GnomeVFSFileSize     *bytes_written,
 	  GnomeVFSContext      *context)
 {
-	DEBUG_PRINT ("do_write: %p\n", method_handle);
+	DEBUG_PRINT ("do_write: %p", method_handle);
 	return gnome_vfs_write_cancellable (((VirtualFileHandle *)method_handle)->handle,
 					    buffer,
 					    num_bytes,
@@ -467,7 +467,7 @@ do_seek (GnomeVFSMethod       *method,
 	 GnomeVFSFileOffset    offset,
 	 GnomeVFSContext      *context)
 {
-	DEBUG_PRINT ("do_seek: %p\n", method_handle);
+	DEBUG_PRINT ("do_seek: %p", method_handle);
 	return gnome_vfs_seek_cancellable (((VirtualFileHandle *)method_handle)->handle,
 					   whence,
 					   offset,
@@ -479,7 +479,7 @@ do_tell (GnomeVFSMethod       *method,
 	 GnomeVFSMethodHandle *method_handle,
 	 GnomeVFSFileSize     *offset_return)
 {
-	DEBUG_PRINT ("do_tell: %p\n", method_handle);
+	DEBUG_PRINT ("do_tell: %p", method_handle);
 	return gnome_vfs_tell (((VirtualFileHandle *)method_handle)->handle,
 			       offset_return);
 }
@@ -490,7 +490,7 @@ do_truncate_handle (GnomeVFSMethod       *method,
 		    GnomeVFSFileSize      where,
 		    GnomeVFSContext      *context)
 {
-	DEBUG_PRINT ("do_truncate_handle: %p\n", method_handle);
+	DEBUG_PRINT ("do_truncate_handle: %p", method_handle);
 	return gnome_vfs_truncate_handle_cancellable (((VirtualFileHandle *)method_handle)->handle,
 						      where,
 						      context);
@@ -509,7 +509,7 @@ do_open_directory (GnomeVFSMethod         *method,
 	GnomeVFSResult          ret;
 	gboolean                res;
 
-	DEBUG_PRINT ("do_open_directory: %s\n", uri->text);
+	DEBUG_PRINT ("do_open_directory: %s", uri->text);
 
 	g_return_val_if_fail (uri != NULL, GNOME_VFS_ERROR_BAD_PARAMETERS);
 
@@ -568,7 +568,7 @@ do_close_directory (GnomeVFSMethod       *method,
 	VirtualDirHandle *handle = (VirtualDirHandle *)method_handle;
 	int i;
 
-	DEBUG_PRINT ("do_close_directory: %p\n", method_handle);
+	DEBUG_PRINT ("do_close_directory: %p", method_handle);
 	for (i = 0; i < handle->n_items * 2; i++) {
 		g_free (handle->listing [i]);
 	}
@@ -608,7 +608,7 @@ do_read_directory (GnomeVFSMethod       *method,
 	char             *path;
 	GnomeVFSURI      *file_uri;
 
-	DEBUG_PRINT ("do_read_directory: %p\n", method_handle);
+	DEBUG_PRINT ("do_read_directory: %p", method_handle);
 
 	while (TRUE) {
 		if (handle->pos >= handle->n_items) {
@@ -658,7 +658,7 @@ do_get_file_info (GnomeVFSMethod         *method,
 	char                   *path;
 	MappingProtocolMessage *reply;
 
-	DEBUG_PRINT ("do_get_file_info: %s\n", uri->text);
+	DEBUG_PRINT ("do_get_file_info: %s", uri->text);
 
 	path = get_path_from_uri (uri);
 	if (path == NULL) {
@@ -676,12 +676,12 @@ do_get_file_info (GnomeVFSMethod         *method,
 
 	if (! res) {
 		ret = GNOME_VFS_ERROR_IO;
-		DEBUG_PRINT ("do_get_file_info: file %s IO ERROR\n", path);
+		DEBUG_PRINT ("do_get_file_info: file %s IO ERROR", path);
 		goto out;
 	}
 
 	ret = MAPPING_PROTOCOL_REPLY (reply)->result;
-	DEBUG_PRINT ("do_get_file_info: file %s result %s\n", path, gnome_vfs_result_to_string (ret));
+	DEBUG_PRINT ("do_get_file_info: file %s result %s", path, gnome_vfs_result_to_string (ret));
 
 	if (ret == GNOME_VFS_ERROR_IS_DIRECTORY) {
 		file_info->name = g_path_get_basename (path);
@@ -713,7 +713,7 @@ do_get_file_info_from_handle (GnomeVFSMethod         *method,
 {
 	GnomeVFSResult res;
 
-	DEBUG_PRINT ("do_get_file_info_from_handle: %p\n", method_handle);
+	DEBUG_PRINT ("do_get_file_info_from_handle: %p", method_handle);
 	res = gnome_vfs_get_file_info_from_handle_cancellable (((VirtualFileHandle *)method_handle)->handle,
 							       file_info, options, context);
 	/* TODO: Need to fill out the real name here. Need to wrap method_handle */
@@ -731,7 +731,7 @@ do_make_directory (GnomeVFSMethod  *method,
 	char                   *path;
 	MappingProtocolMessage *reply;
 
-	DEBUG_PRINT ("do_make_directory: %s\n", uri->text);
+	DEBUG_PRINT ("do_make_directory: %s", uri->text);
 
 	path = get_path_from_uri (uri);
 	if (path == NULL) {
@@ -768,7 +768,7 @@ do_remove_directory (GnomeVFSMethod  *method,
 	char                   *path;
 	MappingProtocolMessage *reply;
 
-	DEBUG_PRINT ("do_remove_directory: %s\n", uri->text);
+	DEBUG_PRINT ("do_remove_directory: %s", uri->text);
 
 	path = get_path_from_uri (uri);
 	if (path == NULL) {
@@ -805,7 +805,7 @@ do_unlink (GnomeVFSMethod  *method,
 	GnomeVFSResult res;
 	char          *path;
 
-	DEBUG_PRINT ("do_remove_directory: %s\n", uri->text);
+	DEBUG_PRINT ("do_remove_directory: %s", uri->text);
 
 	path = get_path_from_uri (uri);
 	if (path == NULL) {
@@ -831,7 +831,7 @@ do_move (GnomeVFSMethod  *method,
 	char                   *old_path;
 	char                   *new_path;
 
-	DEBUG_PRINT ("do_move (%s, %s)\n", old_uri->text, new_uri->text);
+	DEBUG_PRINT ("do_move (%s, %s)", old_uri->text, new_uri->text);
 
 	if (strcmp (new_uri->method_string,
 		    old_uri->method_string) != 0) {
@@ -912,7 +912,7 @@ do_set_file_info (GnomeVFSMethod         *method,
 	MappingProtocolMessage *reply;
 	GnomeVFSURI            *file_uri = NULL;
 
-	DEBUG_PRINT ("do_set_file_info: %s\n", uri->text);
+	DEBUG_PRINT ("do_set_file_info: %s", uri->text);
 
 	full_name = get_path_from_uri (uri);
 	if (full_name == NULL) {
@@ -1013,7 +1013,7 @@ do_truncate (GnomeVFSMethod   *method,
 	char                   *path;
 	MappingProtocolMessage *reply;
 
-	DEBUG_PRINT ("do_truncate: %s\n", uri->text);
+	DEBUG_PRINT ("do_truncate: %s", uri->text);
 
 	path = get_path_from_uri (uri);
 	if (path == NULL) {
@@ -1057,7 +1057,7 @@ do_create_symbolic_link (GnomeVFSMethod  *method,
 	char                   *path;
 	char                   *target_path;
 
-	DEBUG_PRINT ("do_create_symbolic_link: %s -> %s\n", uri->text, target_reference);
+	DEBUG_PRINT ("do_create_symbolic_link: %s -> %s", uri->text, target_reference);
 
 	path = get_path_from_uri (uri);
 	if (path == NULL) {
@@ -1114,7 +1114,7 @@ do_monitor_add (GnomeVFSMethod        *method,
 	monitor->uri = uri;
 	gnome_vfs_uri_ref (uri);
 
-	DEBUG_PRINT ("do_monitor_add: %p path: %s\n", monitor, path);
+	DEBUG_PRINT ("do_monitor_add: %p path: %s", monitor, path);
 
 	reply = NULL;
 	res = request_op (MAPPING_PROTOCOL_OP_MONITOR_ADD,
@@ -1136,7 +1136,7 @@ do_monitor_add (GnomeVFSMethod        *method,
 
 	g_free (path);
 
-	DEBUG_PRINT ("do_monitor_add: DONE %p\n", monitor);
+	DEBUG_PRINT ("do_monitor_add: DONE %p", monitor);
 
 	return GNOME_VFS_OK;
 }
@@ -1153,7 +1153,7 @@ do_monitor_cancel (GnomeVFSMethod       *method,
 
 	monitor = (VirtualFileMonitorHandle *) method_handle;
 
-	DEBUG_PRINT ("do_monitor_cancel: %p\n", monitor);
+	DEBUG_PRINT ("do_monitor_cancel: %p", monitor);
 
 	if (monitor->cancelled)
 		return GNOME_VFS_OK;
@@ -1377,10 +1377,6 @@ vfs_module_init (const char *method_name,
 	daemon_ioc = mapping_protocol_channel_new (daemon_fd);
 	mapping_protocol_channel_set_message_handler (daemon_ioc, handle_message, NULL);
 
-#ifdef DEBUG_ENABLE
-	debug_init ();
-#endif
-
 	return &method;
 }
 
@@ -1388,9 +1384,4 @@ void
 vfs_module_shutdown (GnomeVFSMethod *method)
 {
 	mapping_protocol_channel_unref (daemon_ioc);
-
-#ifdef DEBUG_ENABLE
-	fclose (debug_out);
-#endif
-
 }
