@@ -140,7 +140,9 @@ open_ioctl_handle (const char *device)
 	int fd;
 
  	if ((fd = g_open (device, O_RDWR | O_EXCL | O_NONBLOCK, 0)) < 0
- 	    && (fd = g_open (device, O_RDONLY | O_EXCL | O_NONBLOCK, 0)) < 0) {
+ 	    && (fd = g_open (device, O_RDONLY | O_EXCL | O_NONBLOCK, 0)) < 0
+	    && (fd = g_open (device, O_RDONLY | O_NONBLOCK, 0)) < 0) {
+
 		return INVALID_HANDLE;
 	}
 
@@ -634,6 +636,8 @@ create_command (const char *device)
 	g_ptr_array_add (argv, str);
 	str = g_strdup ("--unmount");
 	g_ptr_array_add (argv, str);
+	str = g_strdup ("--block");
+	g_ptr_array_add (argv, str);
 	str = g_strdup ("--no-ui");
 	g_ptr_array_add (argv, str);
 #else
@@ -670,10 +674,6 @@ unmount_thread_start (void *arg)
 	GError      *error;
 	UnmountData *data;
 	gint         exit_status;
-	char        *envp [] = {
-		"LC_ALL=C",
-		NULL
-	};
 
 	data = arg;
 
@@ -682,8 +682,8 @@ unmount_thread_start (void *arg)
 	error = NULL;
 	if (g_spawn_sync (NULL,
 			  (char **)data->argv->pdata,
-			  envp,
-			  G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL,
+			  NULL,
+			  0,
 			  NULL, NULL,
 			  NULL,
 			  NULL,
@@ -696,7 +696,7 @@ unmount_thread_start (void *arg)
 		}
 
 		/* Delay a bit to make sure unmount finishes */
-		sleep (2);
+		sleep (1);
 	} else {
 		/* spawn failure */
 		if (error) {
@@ -804,7 +804,7 @@ nautilus_burn_drive_eject (NautilusBurnDrive *drive)
 	}
 
 #ifdef USE_GNOME_MOUNT
-	cmd = g_strdup_printf ("gnome-mount --eject --no-ui --device=%s", drive->priv->device);
+	cmd = g_strdup_printf ("gnome-mount --block --eject --no-ui --device=%s", drive->priv->device);
 #else
 	cmd = g_strdup_printf ("eject %s", drive->priv->device);
 #endif
@@ -813,7 +813,7 @@ nautilus_burn_drive_eject (NautilusBurnDrive *drive)
 	g_free (cmd);
 
 	/* delay a bit to make sure eject finishes */
-	sleep (2);
+	sleep (1);
 
 	return res;
 }
